package com.dgtly.order.service;

import com.dgtly.order.domain.DiySalesorgtree;
import com.dgtly.order.domain.DiysalesorgStart;
import com.dgtly.order.domain.OrderCustomers;

import java.util.List;

/**
 * 销售组织架构启用管理Service接口
 * 
 * @author nsy
 * @date 2021-01-19
 */
public interface IDiysalesorgStartService 
{
    /**
     * 查询销售组织架构启用管理
     * 
     * @param salesorgCode 销售组织架构启用管理ID
     * @return 销售组织架构启用管理
     */
    public DiysalesorgStart selectDiysalesorgStartById(String salesorgCode);

    /**
     * 查询销售组织架构启用管理列表
     * 
     * @param diysalesorgStart 销售组织架构启用管理
     * @return 销售组织架构启用管理集合
     */
    public List<DiysalesorgStart> selectDiysalesorgStartList(DiysalesorgStart diysalesorgStart);

    /**
     * 新增销售组织架构启用管理
     * 
     * @param diysalesorgStart 销售组织架构启用管理
     * @return 结果
     */
    public int insertDiysalesorgStart(DiysalesorgStart diysalesorgStart);

    /**
     * 修改销售组织架构启用管理
     * 
     * @param diysalesorgStart 销售组织架构启用管理
     * @return 结果
     */
    public int updateDiysalesorgStart(DiysalesorgStart diysalesorgStart);

    /**
     * 批量删除销售组织架构启用管理
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteDiysalesorgStartByIds(String ids);

    /**
     * 删除销售组织架构启用管理信息
     * 
     * @param salesorgCode 销售组织架构启用管理ID
     * @return 结果
     */
    public int deleteDiysalesorgStartById(String salesorgCode);

    /**
     * 返回销售组织架构列表
     * @param salesorgtree
     * @return
     */
    List<DiySalesorgtree> findSalesOrgList(DiySalesorgtree salesorgtree);

    /**
     * 新增保存销售组织架构启用
     * @param org6codes
     * @param org6names
     * @return
     */
    int saveSalesorgStart(String org6codes,String org6names);
}
